
/*
 * LaTeX Symbols Selector
 *
 * Copyright (C) 2006 Tomasz Mąka <pasp@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef _SEND_H
#define _SEND_H

#define GVIM_SERVERS_LIST_CMD       "gvim --serverlist"
#define GVIM_SERVER_SEND_TEXT_CMD   "gvim --servername %s --remote-send \\%s"

void        drag_and_drop_init          (GtkWidget *widget, GUI *appGUI);
gboolean    send_symbol_to_gvim         (gchar *symbol);
gboolean    send_symbol_to_clipboard    (gchar *symbol);

#endif /* _SEND_H */

